Documentation
¶
Index ¶
- Constants
- type AuthConfig
- type CheckpointCreateOptions
- type CheckpointDeleteOptions
- type CheckpointListOptions
- type CloseWriter
- type CopyToContainerOptions
- type ErrorResponse
- type EventsOptions
- type HijackedResponse
- type NetworkListOptions
- type NodeListOptions
- type NodeRemoveOptions
- type Ping
- type PluginCreateOptions
- type ResizeOptions
- type ServiceCreateOptions
- type ServiceCreateResponse
- type ServiceInspectOptions
- type ServiceListOptions
- type ServiceUpdateOptions
- type SwarmUnlockKeyResponse
- type TaskListOptions
- type Version
Constants ¶
const ( RegistryAuthFromSpec = "spec" RegistryAuthFromPreviousSpec = "previous-spec" )
Values for RegistryAuthFrom in ServiceUpdateOptions
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthConfig ¶
type AuthConfig struct {
Username string `json:"username,omitempty"`
Password string `json:"password,omitempty"`
Auth string `json:"auth,omitempty"`
// Email is an optional value associated with the username.
// This field is deprecated and will be removed in a later
// version of docker.
Email string `json:"email,omitempty"`
ServerAddress string `json:"serveraddress,omitempty"`
// IdentityToken is used to authenticate the user and get
// an access token for the registry.
IdentityToken string `json:"identitytoken,omitempty"`
// RegistryToken is a bearer token to be sent to a registry
RegistryToken string `json:"registrytoken,omitempty"`
}
AuthConfig contains authorization information for connecting to a Registry
type CheckpointCreateOptions ¶
CheckpointCreateOptions holds parameters to create a checkpoint from a container
type CheckpointDeleteOptions ¶
CheckpointDeleteOptions holds parameters to delete a checkpoint from a container
type CheckpointListOptions ¶
type CheckpointListOptions struct {
CheckpointDir string
}
CheckpointListOptions holds parameters to list checkpoints for a container
type CloseWriter ¶
type CloseWriter interface {
CloseWrite() error
}
CloseWriter is an interface that implements structs that close input streams to prevent from writing.
type CopyToContainerOptions ¶
CopyToContainerOptions holds information about files to copy into a container
type ErrorResponse ¶
type ErrorResponse struct {
// The error message.
// Required: true
Message string `json:"message"`
}
ErrorResponse Represents an error. swagger:model ErrorResponse
type EventsOptions ¶
EventsOptions holds parameters to filter events with.
type HijackedResponse ¶
HijackedResponse holds connection information for a hijacked request.
func (*HijackedResponse) Close ¶
func (h *HijackedResponse) Close()
Close closes the hijacked connection and reader.
func (*HijackedResponse) CloseWrite ¶
func (h *HijackedResponse) CloseWrite() error
CloseWrite closes a readWriter for writing.
type NetworkListOptions ¶
NetworkListOptions holds parameters to filter the list of networks with.
type NodeListOptions ¶
NodeListOptions holds parameters to list nodes with.
type NodeRemoveOptions ¶
type NodeRemoveOptions struct {
Force bool
}
NodeRemoveOptions holds parameters to remove nodes with.
type PluginCreateOptions ¶
type PluginCreateOptions struct {
RepoName string
}
PluginCreateOptions hold all options to plugin create.
type ResizeOptions ¶
ResizeOptions holds parameters to resize a tty. It can be used to resize container ttys and exec process ttys too.
type ServiceCreateOptions ¶
type ServiceCreateOptions struct {
// EncodedRegistryAuth is the encoded registry authorization credentials to
// use when updating the service.
//
// This field follows the format of the X-Registry-Auth header.
EncodedRegistryAuth string
// QueryRegistry indicates whether the service update requires
// contacting a registry. A registry may be contacted to retrieve
// the image digest and manifest, which in turn can be used to update
// platform or other information about the service.
QueryRegistry bool
}
ServiceCreateOptions contains the options to use when creating a service.
type ServiceCreateResponse ¶
type ServiceCreateResponse struct {
// ID is the ID of the created service.
ID string
// Warnings is a set of non-fatal warning messages to pass on to the user.
Warnings []string `json:",omitempty"`
}
ServiceCreateResponse contains the information returned to a client on the creation of a new service.
type ServiceInspectOptions ¶
type ServiceInspectOptions struct {
InsertDefaults bool
}
ServiceInspectOptions holds parameters related to the "service inspect" operation.
type ServiceListOptions ¶
ServiceListOptions holds parameters to list services with.
type ServiceUpdateOptions ¶
type ServiceUpdateOptions struct {
// EncodedRegistryAuth is the encoded registry authorization credentials to
// use when updating the service.
//
// This field follows the format of the X-Registry-Auth header.
EncodedRegistryAuth string
// RegistryAuthFrom specifies where to find the registry authorization
// credentials if they are not given in EncodedRegistryAuth. Valid
// values are "spec" and "previous-spec".
RegistryAuthFrom string
// Rollback indicates whether a server-side rollback should be
// performed. When this is set, the provided spec will be ignored.
// The valid values are "previous" and "none". An empty value is the
// same as "none".
Rollback string
// QueryRegistry indicates whether the service update requires
// contacting a registry. A registry may be contacted to retrieve
// the image digest and manifest, which in turn can be used to update
// platform or other information about the service.
QueryRegistry bool
}
ServiceUpdateOptions contains the options to be used for updating services.
type SwarmUnlockKeyResponse ¶
type SwarmUnlockKeyResponse struct {
// UnlockKey is the unlock key in ASCII-armored format.
UnlockKey string
}
SwarmUnlockKeyResponse contains the response for Engine API: GET /swarm/unlockkey
type TaskListOptions ¶
TaskListOptions holds parameters to list tasks with.
type Version ¶
type Version struct {
Platform struct{ Name string } `json:",omitempty"`
Version string
APIVersion string `json:"ApiVersion"`
MinAPIVersion string `json:"MinAPIVersion,omitempty"`
GitCommit string
GoVersion string
Os string
Arch string
KernelVersion string `json:",omitempty"`
Experimental bool `json:",omitempty"`
BuildTime string `json:",omitempty"`
}
Version contains response of Engine API: GET "/version"